base Package
============

:mod:`base` Package
-------------------

.. automodule:: stoqlib.gui.base
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`columns` Module
---------------------

.. automodule:: stoqlib.gui.base.columns
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dialogs` Module
---------------------

.. automodule:: stoqlib.gui.base.dialogs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`gtkadds` Module
---------------------

.. automodule:: stoqlib.gui.base.gtkadds
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`lists` Module
-------------------

.. automodule:: stoqlib.gui.base.lists
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`messagebar` Module
------------------------

.. automodule:: stoqlib.gui.base.messagebar
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`search` Module
--------------------

.. automodule:: stoqlib.gui.base.search
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`slaves` Module
--------------------

.. automodule:: stoqlib.gui.base.slaves
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`wizards` Module
---------------------

.. automodule:: stoqlib.gui.base.wizards
    :members:
    :undoc-members:
    :show-inheritance:

